==> nui_core-0.0.85.tar.gz: lib/ui/styling/nui_box_decoration.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/ui/styling/nui_linear_gradient.dart';

class NUIBoxDecoration extends BoxDecoration{
  NUIBoxDecoration({final BoxShape shape:BoxShape.rectangle, final double borderRadiusCircular:0, final Offset shadowOffset, final BorderRadius borderRadius, this.shadowRadius:0, this.color, this.spreadRadius, this.shadowColor:NUIColors.NUIShadowBlack, this.gradient})
  : super(shape: shape, borderRadius: borderRadius ?? (shape == BoxShape.rectangle ? BorderRadius.circular(borderRadiusCircular) : null), color: color, boxShadow:shadowRadius > 0 ? [BoxShadow(spreadRadius: spreadRadius ?? 0, blurRadius: shadowRadius, color: shadowColor, offset: shadowOffset ?? Offset(0, 0))] : null, gradient: gradient);
  final double shadowRadius;
  final Color color;
  final double spreadRadius;
  final Color shadowColor;
  final NUILinearGradient gradient;
}

class NUIOutlineDecoration extends BoxDecoration{
  NUIOutlineDecoration({this.thickness: 2, this.radius, this.gradient, @required this.outlineColor, this.shadowColor:NUIColors.NUIShadowBlack, this.shadowRadius: 0, this.innerColor}): super(color: innerColor, border: Border.all(width: thickness, color: outlineColor), borderRadius: radius, boxShadow:shadowRadius > 0 ? [BoxShadow(blurRadius: shadowRadius, color: shadowColor)] : null, gradient: gradient);
  final double shadowRadius;
  final double thickness;
  final BorderRadius radius;
  final Color outlineColor;
  final Color shadowColor;
  final Color innerColor;
  final NUILinearGradient gradient;
}

==> nui_core-0.0.127.tar.gz: lib/ui/styling/nui_box_decoration.dart <==
import 'package:flutter/cupertino.dart';
import 'package:nui_core/color/nui_colors.dart';
import 'package:nui_core/ui/styling/nui_linear_gradient.dart';

class NUIBoxDecoration extends BoxDecoration{
  NUIBoxDecoration({final BoxShape shape:BoxShape.rectangle, final double borderRadiusCircular:0, final Offset shadowOffset, final BorderRadius borderRadius, this.shadowRadius:0, this.color, this.spreadRadius, this.shadowColor:NUIColors.NUIShadowBlack, this.gradient})
  : super(shape: shape, borderRadius: borderRadius ?? (shape == BoxShape.rectangle ? BorderRadius.circular(borderRadiusCircular) : null), color: color, boxShadow:shadowRadius > 0 ? [BoxShadow(spreadRadius: spreadRadius ?? 0, blurRadius: shadowRadius, color: shadowColor, offset: shadowOffset ?? Offset(0, 0))] : null, gradient: gradient);
  final double shadowRadius;
  final Color color;
  final double spreadRadius;
  final Color shadowColor;
  final NUILinearGradient gradient;
}

class NUIOutlineDecoration extends BoxDecoration{
  NUIOutlineDecoration({this.thickness: 2, this.borderRadius, this.gradient, @required this.outlineColor, this.shadowColor:NUIColors.NUIShadowBlack, this.shadowRadius: 0, this.innerColor}): super(color: innerColor, border: Border.all(width: thickness, color: outlineColor), borderRadius: borderRadius, boxShadow:shadowRadius > 0 ? [BoxShadow(blurRadius: shadowRadius, color: shadowColor)] : null, gradient: gradient);
  final double shadowRadius;
  final double thickness;
  final BorderRadius borderRadius;
  final Color outlineColor;
  final Color shadowColor;
  final Color innerColor;
  final NUILinearGradient gradient;
}
